@@ -13,11 +13,10 @@
 #' @usage
 #' mbl(Xr, Yr, Xu, Yu = NULL, k, k_diss, k_range, spike = NULL,
 #'     method = local_fit_wapls(min_pls_c = 3, max_pls_c = min(dim(Xr), 15)),
-#'     diss_method = "pca", diss_usage = "predictors",
-#'     gh = TRUE, pc_selection = list(method = "opc", value = min(dim(Xr), 40)),
-#'     control = mbl_control(), group = NULL,
-#'     center = TRUE, scale = FALSE, verbose = TRUE, 
-#'     documentation = character(), ...)
+#'     diss_method = "pca", diss_usage = "predictors", gh = TRUE, 
+#'     pc_selection = list(method = "opc", value = min(dim(Xr), 40)),
+#'     control = mbl_control(), group = NULL, center = TRUE, scale = FALSE,
+#'     verbose = TRUE, documentation = character(), seed = NULL, ...) 
 #'
 #' @param Xr a matrix of predictor variables of the reference data
 #' (observations in rows and variables in columns).
@@ -181,6 +180,10 @@
 #' @param verbose a logical indicating whether or not to print a progress bar
 #' for each observation to be predicted. Default is \code{TRUE}. Note: In case
 #' parallel processing is used, these progress bars will not be printed.
+#' @param seed an integer value containing the random number generator (RNG) 
+#' state for random number generation. This argument can be used for 
+#' reproducibility purposes (for random sampling) in the cross-validation 
+#' results. Default is \code{NULL}, i.e. no RNG is applied.
 #' @param documentation an optional character string that can be used to
 #' describe anything related to the \code{mbl} call (e.g. description of the
 #' input data). Default: \code{character()}. NOTE: his is an experimental
@@ -348,8 +351,9 @@
 #'    function.
 #'    See \code{.local} argument in the \code{\link{ortho_diss}} function.}
 #'    }
-#'  \item{\code{documentation}}{ A character string with the documentation
-#'  added.}
+#'  \item{\code{seed}}{ a value mirroing the one passed to seed.}
+#'  \item{\code{documentation}:}{ a character string mirroring the one provided
+#'  in the \code{documentation} argument.}
 #'  }
 #' When the \code{k_diss} argument is used, the printed results show a table
 #' with a column named '\code{p_bounded}. It represents the percentage of
@@ -389,7 +393,7 @@
 #'
 #' @seealso \code{\link{mbl_control}}, \code{\link{f_diss}},
 #' \code{\link{cor_diss}}, \code{\link{sid}}, \code{\link{ortho_diss}},
-#' \code{\link{search_neighbors}}
+#' \code{\link{search_neighbors}},  \code{\link{local_fit}}
 #' @examples
 #' \donttest{
 #' library(prospectr)
@@ -669,6 +673,7 @@ mbl <- function(Xr, Yr, Xu, Yu = NULL,
                 scale = FALSE,
                 verbose = TRUE,
                 documentation = character(),
+                seed = NULL, 
                 ...) {
   f_call <- match.call()
 
@@ -1087,7 +1092,8 @@ mbl <- function(Xr, Yr, Xu, Yu = NULL,
   n_iter <- nrow(Xu)
 
   pred_obs <- foreach(
-    i = 1:n_iter, ith_observation = iter_neighborhoods,
+    i = 1:n_iter, 
+    ith_observation = iter_neighborhoods,
     .inorder = FALSE,
     .export = c(
       "ortho_diss", "fit_and_predict", "pls_cv",
@@ -1188,7 +1194,7 @@ mbl <- function(Xr, Yr, Xu, Yu = NULL,
         } else {
           kth_weights <- rep(1, current_k)
         }
-
+        
         # local fit
         i_k_pred <- fit_and_predict(
           x = i_k_xr,
@@ -1206,7 +1212,9 @@ mbl <- function(Xr, Yr, Xu, Yu = NULL,
           noise_variance = method$noise_variance,
           range_prediction_limits = control$range_prediction_limits,
           pls_max_iter = 1,
-          pls_tol = 1e-6
+          pls_tol = 1e-6, 
+          seed = seed,
+          modified = ifelse(is.null(method$modified), FALSE, method$modified) ## applies to pls only 
         )
 
         ith_pred_results$pred[kk] <- i_k_pred$prediction
@@ -1262,7 +1270,9 @@ mbl <- function(Xr, Yr, Xu, Yu = NULL,
             tune = FALSE,
             range_prediction_limits = control$range_prediction_limits,
             pls_max_iter = 1,
-            pls_tol = 1e-6
+            pls_tol = 1e-6,
+            seed = seed,
+            modified = ifelse(is.null(method$modified), FALSE, method$modified) ## applies to pls only 
           )$prediction
 
           ith_pred_results$y_nearest_pred[kk] <- nearest_pred / kth_weights[1]
@@ -1474,7 +1484,8 @@ mbl <- function(Xr, Yr, Xu, Yu = NULL,
       Yu_prediction_statistics = pred_res
     ),
     results = results_table,
-    documentation = documentation
+    documentation = documentation, 
+    seed = seed
   )
 
   attr(results_list, "call") <- f_call
