@@ -13,21 +13,20 @@ print.ortho_projection <- function(x, ...) {
   cat("\n", "Method: ", x$method)
   cat("\n", "Number of components retained: ", x$n_components, "\n")
   cat(" Number of observations and number of original variables: ", c(nrow(x$scores), ncol(x$X_loadings)), "\n")
-
+  cat(paste0(" Original variance in Xr: ",  round(x$variance$original_x_var, 3), "\n"))
+  
   if (any(grepl("Xu", rownames(x$scores)))) {
     mss <- c("\n", "Explained variance in X {Xr; Xu}: \n")
   } else {
     mss <- c("\n", "Explained variance in Xr: \n")
   }
-
-  cat("\n", "Standard deviations, individual explained variance, cumulative explained variance:", "\n")
-  if (x$method == "pls") {
-    cat(mss)
-    print(x$variance$x_var, digits = 3)
+  
+  cat("\n", "Explained variances, ratio of explained variance, cumulative explained variance:", "\n")
+  cat(mss)
+  print(x$variance$x_var, digits = 3)
+  
+  if (x$method %in% c("pls", "mpls")) {
     cat("\n", "Explained variance in Yr: \n")
     print(x$variance$y_var, digits = 3)
-  } else {
-    cat(mss)
-    print(x$variance, digits = 3)
   }
 }
